@@ -13,7 +13,7 @@ from pycfmodel.model.resources.resource import Resource
 
 from cfripper.cloudformation_actions_only_accepts_wildcard import CLOUDFORMATION_ACTIONS_ONLY_ACCEPTS_WILDCARD
 from cfripper.config.regex import REGEX_IS_STAR
-from cfripper.model.enums import RuleGranularity
+from cfripper.model.enums import RuleGranularity, RuleMode
 from cfripper.model.result import Result
 from cfripper.rules.base_rules import ResourceSpecificRule
 
@@ -78,7 +78,7 @@ class WildcardResourceRule(ResourceSpecificRule):
 
         if statement.actions_with(REGEX_IS_STAR):
             if statement.Condition:
-                self._add_to_result(result, logical_id, policy_name, None, statement, extras, warning=True)
+                self._add_to_result(result, logical_id, policy_name, None, statement, extras, monitor=True)
             else:
                 self._add_to_result(result, logical_id, policy_name, None, statement, extras)
         else:
@@ -91,7 +91,7 @@ class WildcardResourceRule(ResourceSpecificRule):
                     # Source: https://docs.aws.amazon.com/kms/latest/developerguide/key-policies.html
                     logger.info(f"KMS Action {action} only accepts wildcard, ignoring...")
                 elif statement.Condition:
-                    self._add_to_result(result, logical_id, policy_name, action, statement, extras, warning=True)
+                    self._add_to_result(result, logical_id, policy_name, action, statement, extras, monitor=True)
                 else:
                     self._add_to_result(result, logical_id, policy_name, action, statement, extras)
 
@@ -103,15 +103,15 @@ class WildcardResourceRule(ResourceSpecificRule):
         action: Optional[str],
         statement: Statement,
         extras: Dict,
-        warning: bool = False,
+        monitor: bool = False,
     ):
-        add_to_result = self.add_warning_to_result if warning else self.add_failure_to_result
-        add_to_result(
+        self.add_failure_to_result(
             result=result,
             reason=self._build_reason(logical_id, action, policy_name),
             granularity=RuleGranularity.ACTION,
             resource_ids={logical_id},
             actions=set(statement.get_action_list()),
+            rule_mode=RuleMode.MONITOR if monitor else None,
             context={
                 "config": self._config,
                 "extras": extras,
